connectionCount property
int
get
connectionCount
The number of connections currently pooled, across every host.
Implementation
int get connectionCount => _pools.values.map((pool) => pool.size).sum;
The number of connections currently pooled, across every host.
int get connectionCount => _pools.values.map((pool) => pool.size).sum;