ClientTransportConnection class abstract

Inheritance

Constructors

ClientTransportConnection.viaSocket(Socket socket, {ClientSettings? settings})
factory
ClientTransportConnection.viaStreams(Stream<List<int>> incoming, StreamSink<List<int>> outgoing, {ClientSettings? settings})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isOpen → bool
Whether this connection is open and can be used to make new requests via makeRequest.
no setter
onActiveStateChanged ← ActiveStateHandler
Sets the active state callback.
no getterinherited
onFrameReceived → Stream<void>
Stream which emits an event every time a ping is received on this connection.
no setterinherited
onInitialPeerSettingsReceived → Future<void>
Future which completes when the first SETTINGS frame is received from the peer.
no setterinherited
onPingReceived → Stream<int>
Stream which emits an event with the ping id every time a ping is received on this connection.
no setterinherited
peerMaxConcurrentStreams → int?
The maximum number of concurrent streams the peer currently allows, per its most recent SETTINGS_MAX_CONCURRENT_STREAMS (RFC 7540 6.5.2), or null if the peer hasn't advertised a limit.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

finish() → Future
Finish this connection.
inherited
makeRequest(List<Header> headers, {bool endStream = false}) → ClientTransportStream
Creates a new outgoing stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ping() → Future
Pings the other end.
inherited
terminate([int? errorCode, String? message]) → Future
Terminates this connection forcefully.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited