ServerSettings class

Settings for a TransportConnection a server can make.

Inheritance

Constructors

ServerSettings({int? concurrentStreamLimit, int? streamWindowSize})
const

Properties

concurrentStreamLimit → int?
The maximum number of concurrent streams the remote end can open (defaults to being unlimited).
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamWindowSize → int?
The default stream window size the remote peer can use when creating new streams (defaults to 65535 bytes).
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited