TransportConnectionException class

An exception thrown when a HTTP/2 connection error occurred.

Inheritance

Constructors

TransportConnectionException(int errorCode, String details)

Properties

errorCode → int
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited